Package: UKFE
Type: Package
Title: UK Flood Estimation
Version: 2.0.2
Authors@R: person(given = "Anthony",
                    family = "Hammond",
                    role = c("aut", "cre"),
                    email = "agqhammond@gmail.com")
Maintainer: Anthony Hammond <agqhammond@gmail.com>
Description: Functions to implement the methods of the Flood Estimation Handbook (FEH), associated updates and the revitalised flood hydrograph model (ReFH). Currently the package uses NRFA peak flow dataset version 14. Aside from FEH functionality, further hydrological functions are available. Most of the methods implemented in this package are described in one or more of the following: "Flood Estimation Handbook", Centre for Ecology & Hydrology (1999, ISBN:0 948540 94 X). "Flood Estimation Handbook Supplementary Report No. 1", Kjeldsen (2007, ISBN:0 903741 15 7). "Regional Frequency Analysis - an approach based on L-moments", Hosking & Wallis (1997, ISBN: 978 0 521 01940 8). "Making better use of local data in flood frequency estimation", Environment Agency (2017, ISBN: 978 1 84911 387 8). "Sampling uncertainty of UK design flood estimation" , Hammond (2021, <doi:10.2166/nh.2021.059>). "The FEH 2025 statistical method update", UK Centre for Ecology and Hydrology (2025). "Low flow estimation in the United Kingdom", Institute of Hydrology (1992, ISBN 0 948540 45 1). Data from the UK National River Flow Archive (<https://nrfa.ceh.ac.uk/>, terms and conditions: <https://nrfa.ceh.ac.uk/help/costs-terms-and-conditions>).
URL: https://agqhammond.github.io/UKFE/,
        https://github.com/agqhammond/UKFE
BugReports: https://github.com/agqhammond/UKFE/issues
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
Depends: R (>= 3.5.0)
VignetteBuilder: knitr
Imports: xml2, methods, sf
Suggests: knitr, rmarkdown
NeedsCompilation: no
Packaged: 2026-06-19 14:02:10 UTC; AnthonyHammond
Author: Anthony Hammond [aut, cre]
Repository: CRAN
Date/Publication: 2026-06-19 14:40:02 UTC
Built: R 4.6.0; ; 2026-06-19 15:43:37 UTC; unix
