---
title: "Troubleshooting common errors"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Troubleshooting common errors}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

This vignette will be updated as common issues arise.
If you encounter a problem, please open a GitHub issue at <https://github.com/agqhammond/UKFE/issues>.
Confirmed issues will be documented here together with reproducible examples and solutions.
